..
    This file is part of Invenio
    Copyright (C) 2015 CERN.

    Invenio is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.

    Invenio is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Invenio; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.

    In applying this licence, CERN does not waive the privileges and immunities
    granted to it by virtue of its status as an Intergovernmental Organization
    or submit itself to any jurisdiction.

Authors
=======

Invenio Groups is a module developed for the `Invenio
<http://invenio-software.org>`_ digital library software.

Contact us at `info@invenio-software.org
<mailto:info@invenio-software.org>`_.

- Benoit Thiell <bthiell@cfa.harvard.edu>
- Diane Berkovits <diane.berkovits@cern.ch>
- Eirini Psallida <eirini.psallida@cern.ch>
- Gregory Favre <gregory.favre@cern.ch>
- Guillaume Lastecoueres <PX9e@gmx.fr>
- Javier Martin <javier.martin.montull@cern.ch>
- Jerome Caffaro <jerome.caffaro@cern.ch>
- Jiri Kuncar <jiri.kuncar@cern.ch>
- Kamil Neczaj <kamil.neczaj@cern.ch>
- Leonardo Rossi <leonardo.r@cern.ch>
- Raquel Jimenez Encinar <raquel.jimenez.encinar@cern.ch>
- Samuele Kaplun <samuele.kaplun@cern.ch>
- Tibor Simko <tibor.simko@cern.ch>
- Yoan Blanc <yoan.blanc@cern.ch>
- Adrian Pawel Baran <adrian.pawel.baran@cern.ch>
- Lars Holm Nielsen <lars.holm.nielsen@cern.ch>
- Konstantinos Kostis <konstantinos.kostis@cern.ch>
- Charlotte Cattaneo <ciris.cattaneo@gmail.com>
